==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ValueBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ValueBrushScaleDescription } from "./ValueBrushScaleDescription";
/**
 * @hidden
 */
export let ValueBrushScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class ValueBrushScaleDescriptionMetadata extends Base {
        static b(a) {
            if (ValueBrushScaleDescriptionMetadata.a == null) {
                ValueBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ValueBrushScaleDescriptionMetadata.c(ValueBrushScaleDescriptionMetadata.a);
            }
            if (a.j(ValueBrushScaleDescriptionMetadata.a)) {
                return;
            }
            a.y(ValueBrushScaleDescriptionMetadata.a);
        }
        static c(a) {
            BrushScaleDescriptionMetadata.c(a);
            a.item("MinimumValue", "Number:double");
            a.item("MaximumValue", "Number:double");
            a.item("IsLogarithmic", "Boolean");
            a.item("LogarithmBase", "Number:int");
        }
        static d(a) {
            ValueBrushScaleDescriptionMetadata.b(a);
            a.aa("ValueBrushScale", () => new ValueBrushScaleDescription());
            a.z("ValueBrushScale", ValueBrushScaleDescriptionMetadata.a);
        }
    }
    ValueBrushScaleDescriptionMetadata.$t = /*@__PURE__*/ markType(ValueBrushScaleDescriptionMetadata, 'ValueBrushScaleDescriptionMetadata');
    ValueBrushScaleDescriptionMetadata.a = null;
    return ValueBrushScaleDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ValueBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { ValueBrushScaleDescription } from "./ValueBrushScaleDescription";
/**
 * @hidden
 */
export let ValueBrushScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class ValueBrushScaleDescriptionMetadata extends Base {
        static b(a) {
            if (ValueBrushScaleDescriptionMetadata.a == null) {
                ValueBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ValueBrushScaleDescriptionMetadata.c(ValueBrushScaleDescriptionMetadata.a);
            }
            if (a.k(ValueBrushScaleDescriptionMetadata.a)) {
                return;
            }
            a.aa(ValueBrushScaleDescriptionMetadata.a);
        }
        static c(a) {
            BrushScaleDescriptionMetadata.c(a);
            a.item("MinimumValue", "Number:double");
            a.item("MaximumValue", "Number:double");
            a.item("IsLogarithmic", "Boolean");
            a.item("LogarithmBase", "Number:int");
        }
        static d(a) {
            ValueBrushScaleDescriptionMetadata.b(a);
            a.ac("ValueBrushScale", () => new ValueBrushScaleDescription());
            a.ab("ValueBrushScale", ValueBrushScaleDescriptionMetadata.a);
        }
    }
    ValueBrushScaleDescriptionMetadata.$t = /*@__PURE__*/ markType(ValueBrushScaleDescriptionMetadata, 'ValueBrushScaleDescriptionMetadata');
    ValueBrushScaleDescriptionMetadata.a = null;
    return ValueBrushScaleDescriptionMetadata;
})();
